========
Features
========

Here's a brief description of the features in Mini-AMF. The
:doc:`CHANGES <../changelog>` document contains a more detailed
summary of all new features.

- :mod:`AMF0 <miniamf.amf0>` encoder/decoder for legacy Adobe Flash
  Players (version 6-8)
- :mod:`AMF3 <miniamf.amf3>` encoder/decoder for the new AMF format in
  Adobe Flash Player 9 and newer
- :doc:`Adapter framework <../architecture/adapters>`
- :mod:`Local Shared Object <miniamf.sol>` support

Also see the plans for :doc:`future development <future>`.
